@@ -60,7 +60,11 @@ impl Default for MsgBoxPropsBuilder {
 
 impl PropsBuilder for MsgBoxPropsBuilder {
     fn build(&mut self) -> Props {
-        self.props.take().unwrap()
+        let mut props: Props = Props::default();
+        if let Some(p) = self.props.take() {
+            props = p;
+        }
+        props
     }
 
     fn hidden(&mut self) -> &mut Self {
